%%
%% This is file `nxtthesis.cls',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% nxtlatex.dtx  (with options: `nxtthesis')
%% 
%% This is a generated file.
%% 
%% Copyright (C) 2025 Volker Reichenberger.
%% 
%% This file is part of the nxtlatex package.
%% 
%% This file may be distributed and/or modified under the conditions
%% of the LaTeX Project Public License, either version 1.3c of this
%% license or (at your option) any later version.
%% The latest version of this license is in
%%    https://www.latex-project.org/lppl.txt
%% and version 1.3c or later is part of all distributions of LaTeX
%% version 2008 or later.
%% 
\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{nxtthesis}[2026/04/21 v1.2 NXT Thesis Class (LuaLaTeX)]

\LoadClass{scrreprt}

\RequirePackage{kvoptions}
\SetupKeyvalOptions{family=nxtthesis,prefix=nxtthesis@}

\DeclareBoolOption{german}
\DeclareBoolOption{english}
\DeclareBoolOption{gyre}
\DeclareBoolOption{libertinus}
\DeclareBoolOption{segoeui}
\DeclareBoolOption{stix}
\DeclareBoolOption{fira}

\ProcessKeyvalOptions*

\ifnxtthesis@german
  \RequirePackage[ngerman]{babel}
\else
  \ifnxtthesis@english
    \RequirePackage[english]{babel}
  \else
    \RequirePackage[ngerman]{babel}
  \fi
\fi

\RequirePackage{fontspec}
\RequirePackage{etoolbox}

\ifnxtthesis@gyre
  \setmainfont{TeX Gyre Pagella}
  \setsansfont{TeX Gyre Heros}
  \RequirePackage{unicode-math}
  \setmathfont{TeX Gyre Pagella Math}
\fi

\ifnxtthesis@libertinus
  \setmainfont{Libertinus Serif}
  \setsansfont{Source Sans 3}
  \RequirePackage{unicode-math}
  \setmathfont{Libertinus Math}
\fi

\ifnxtthesis@segoeui
  \setmainfont{Segoe UI}[BoldFont={Segoe UI Semibold}]
  \setsansfont{Segoe UI}[BoldFont={Segoe UI Semibold}]
  \setmonofont{Source Code Pro}[BoldFont={Source Code Pro Semibold}]
  \RequirePackage{unicode-math}
  \setmathfont{Euler Math}
\fi

\ifnxtthesis@stix
  \setmainfont{STIX Two Text}
  \setsansfont{Source Sans 3}
  \RequirePackage{unicode-math}
  \setmathfont{STIX Two Math}
\fi

\ifnxtthesis@fira
  \setmainfont{Fira Sans}[BoldFont={Fira Sans Medium}]
  \setsansfont{Fira Sans}[BoldFont={Fira Sans Medium}]
  \setmonofont{Fira Mono}
  \RequirePackage{unicode-math}
  \setmathfont{Fira Math}
\fi

\RequirePackage{nxtlatexlogos}

\newcommand{\nxtthesis@maybeLogo}{\nxtlogo[width=4cm]}

\def\abgabedatum#1{\def\@abgabedatum{#1}}
\newcommand{\printabgabedatum}{\@abgabedatum}

\def\fakultaet#1{\def\@fakultaet{#1}}
\newcommand{\printfakultaet}{\@fakultaet}

\def\hochschule#1{\def\@hochschule{#1}}
\newcommand{\printhochschule}{\@hochschule}

\def\studiengang#1{\def\@studiengang{#1}}
\newcommand{\printstudiengang}{\@studiengang}

\def\akademischergrad#1{\def\@akademischergrad{#1}}
\newcommand{\printakademischergrad}{\@akademischergrad}

\def\adresse#1{\def\@adresse{#1}}
\newcommand{\printadresse}{\@adresse}

\def\matrikelnummer#1{\def\@matrikelnummer{#1}}
\newcommand{\printmatrikelnummer}{\@matrikelnummer}

\def\erstpruef#1{\def\@erstpruef{#1}}
\newcommand{\printerstpruef}{\@erstpruef}
\def\erstpruefbezeichnung#1{\def\@erstpruefbezeichnung{#1}}
\newcommand{\printerstpruefbezeichnung}{\@erstpruefbezeichnung}

\def\zweitpruef#1{\def\@zweitpruef{#1}}
\newcommand{\printzweitpruef}{\@zweitpruef}
\def\zweitpruefbezeichnung#1{\def\@zweitpruefbezeichnung{#1}}
\newcommand{\printzweitpruefbezeichnung}{\@zweitpruefbezeichnung}

\addtokomafont{disposition}{\rmfamily}
\RedeclareSectionCommand[afterskip=2\baselineskip]{chapter}

\RequirePackage{nxtlatexcolors}

\fakultaet{NXT Nachhaltigkeit und Technologie}
\hochschule{Hochschule Reutlingen}

\RequirePackage{hyperref}
\hypersetup{
  hidelinks
}

\RequirePackage{makeidx}
\makeindex

\RequirePackage{booktabs}

\newcommand{\Index}[1]{\index{#1}\emph{#1}}

\renewcommand*{\maketitle}{%
  \begin{titlepage}
    \begin{center}
      \null\vspace{2cm}
      {\huge\bfseries\@title\par}
      \vfill
      Thesis zur Erlangung des akademischen Grades\\[.5\baselineskip]
      \printakademischergrad\\[.5\baselineskip]
      an der Fakultät \printfakultaet\\
      der \printhochschule\\
      im Studiengang\\[.5\baselineskip]
      \printstudiengang
    \end{center}
    \vfill
    \noindent
    Vorgelegt von:\\
    \@author\\
    \printadresse\\
    Matrikelnummer \printmatrikelnummer\\[24pt]
    \noindent
    Abgabedatum: \@abgabedatum\\[1em]
    \@erstpruefbezeichnung: \@erstpruef\\
    \@zweitpruefbezeichnung: \@zweitpruef
  \end{titlepage}
}

\newcommand{\eigenständigkeitserklärung}{%
  \newpage
  \null\vspace{2cm}
  \noindent
  Ich versichere, dass ich diese Thesis ohne fremde Hilfe selbständig
  verfasst, keine anderen als die angegebenen Quellen und Hilfsmittel
  benutzt sowie alle wörtlichen oder sinngemäß übernommenen Stellen
  in der Arbeit gekennzeichnet habe.
  Die Arbeit wurde noch keiner Kommission zur Prüfung vorgelegt und
  verletzt in keiner Weise Rechte Dritter.
  \vspace{4cm}

  \noindent
  \begin{minipage}[t]{0.45\textwidth}
    \hrulefill\\[0.3ex]
    Ort, Datum
  \end{minipage}%
  \hfill
  \begin{minipage}[t]{0.45\textwidth}
    \hrulefill\\[0.3ex]
    Unterschrift
  \end{minipage}
}
\endinput
%%
%% End of file `nxtthesis.cls'.
